# README

## GENERAL INFO

Project: Asthook  
Contributors: MadSquirrels  
License: GNU General Public License v3.0  
Version: v1.0  
Date: 02-16-20  


## GOAL

Many plugins allowing to analyze the application are already available such as :  
  - searching for literals in the source code
  - Listing set of read and write functions on the file system.
  - searching for exploitable vulnerable Intent and generation of an apk poc
  - listing of all user entry points
  - searching function called in the apk
  - searching function in the apk
  - generating an automatic hook on a function
  - automatic installing of the #certificate
  - automatic bypassing of #SLL #pinning
  - Recovering deleted files
  - Etc.


## READ THE DOCS

To see how to install and how to use follow this link:  
[documentation](https://madsquirrels.gitlab.io/mobile/asthook/)

If you want to know how to install it and use it in local follow this instructions:
 - cd docs
 - pip3.7 install -r requirement.txt
 - make render
 - open your browser and go to 127.0.0.1:8000

## Donation

If you want to support me <3  

[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=FPG4QZWGUTPXW&currency_code=EUR)
